@@ -21,7 +21,7 @@ class Pinyin(object):
     """
 
     data_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
-            'Mandarin.dat')
+                             'Mandarin.dat')
 
     def __init__(self):
         self.dict = {}
@@ -35,13 +35,13 @@ class Pinyin(object):
             key = "%X" % ord(char)
             try:
                 result.append(self.dict[key].split(" ")[0].strip()[:-1]
-                        .lower())
-            except:
+                              .lower())
+            except KeyError:
                 result.append(char)
         return splitter.join(result)
 
     def get_initials(self, char=u'你'):
         try:
             return self.dict["%X" % ord(char)].split(" ")[0][0]
-        except:
+        except KeyError:
             return char
